@@ -7,7 +7,7 @@ use strict;
 
 package Log::Report::Message;
 use vars '$VERSION';
-$VERSION = '1.24';
+$VERSION = '1.25';
 
 
 use Log::Report 'log-report';
@@ -129,8 +129,14 @@ sub toString(;$)
     my $prepend = $self->{_prepend} // '';
     my $append  = $self->{_append}  // '';
 
-    $prepend    = "$prepend" if blessed $prepend;
-    $append     = "$append"  if blessed $append;
+	if(blessed $prepend) {
+        $prepend = $prepend->isa(__PACKAGE__) ? $prepend->toString($locale)
+          : "$prepend";
+	}
+	if(blessed $append) {
+        $append  = $append->isa(__PACKAGE__) ? $append->toString($locale)
+          : "$append";
+	}
 
     $self->{_msgid}   # no translation, constant string
         or return "$prepend$append";
